/**
 * @function doSignup
 * @returns Promise
 */
"use strict";

const Promise = require('apemanpromise'),
    doSignget = require('./do_signget');

/** @lends doSignup */
function doSignup(UserSign, data, digest, signKeys, saltLength) {
    const User = UserSign.getRef('user').model;
    let salt = digest.newSalt(saltLength || 24);
    let user = Object.assign({}, data);
    delete user.password;
    return digest(data.password, salt)
        .then(hash =>
            User
                .create(user)
                .then(user => Promise.all(
                    signKeys.map(signKey =>
                        UserSign.create({
                            user_id: user.id,
                            sign_key_kind: signKey,
                            sign_key: data[signKey],
                            password_salt: salt,
                            password_hash: hash,
                            signup_at: new Date()
                        })
                    )
                    )
                ))
        .then(signs =>
            Promise.all(
                signs.map(sign => doSignget(UserSign, sign))
            )
        );
}

module.exports = doSignup;
